Head models and image reconstruction
====================================

.. py:currentmodule:: cedalion.imagereco


.. autosummary::
   :toctree: _autosummary_imagereco
   :recursive:

   cedalion.geometry

   cedalion.imagereco.forward_model
   cedalion.imagereco.solver
   cedalion.imagereco.tissue_properties
   cedalion.imagereco.utils


Examples
--------

.. nbgallery::
   :glob:

   ../examples/head_models/*